# Ethernet(IEEE 802.3) mit [CSMA/CD](02_HW-BausteineUndVerkabelung.md#csma-cd-protokoll)
## Vollduplex vs Halbduplex
![image_787.png](image_787.png)

### Vollduplex
- von einem Switch zu einem ausgewählten Host
- von einem Switch zu einem anderen Switch
- von einem Host zu einem anderen Host (über ein Crossover Kabel)


## Ethernet Vergleich
|                                         | Klassisches Ethernet                                                                                                         | Fast Ethernet                                                                                                                     | Gigabit-Ethernet                                                                                                                              |
|-----------------------------------------|------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------------------------------------------------|
| Übertragungsgeschwindigkeit             | 10 Mbit/s                                                                                                                    | 100 Mbit/s                                                                                                                        | 1000 Mbit/s (1Gbit/s)                                                                                                                         |
| Übertragungsmedium                      | Koaxialkabel, (später) Twisted-Pair, Glasfaser                                                                               | Twisted-Pair, Glasfaser                                                                                                           | Twisted-Pair(IEEE 802.3ab, längere Distanzen), Glasfaser (kurze Distanzen), 1000BASE-CX(sehr kurze Distanzen)                                 |
| Topologie                               | Bus-Topologie (Koaxialkabel), Stern-Topologie (Geräte über Kabel mit zentralem Hub/Switch verbunden, heute Managed Switches) |                                                                                                                                   |                                                                                                                                               |
| CSMA/CD                                 | wird genutzt                                                                                                                 | Unterstützung, Veränderungen: Notwendigkeit reduziert(Einführung Switches, Full-Duplex-Verbindungen)                              |                                                                                                                                               |
| Adressierung und Rahmenstruktur (Frame) | MAC-Adressen (Identifizierung im LAN-Netzwerk)                                                                               |                                                                                                                                   |                                                                                                                                               |
| Rahmenstruktur (Frame)                  | Präambel und StartFrame-Delimiter, Ziel-/Quelladressen, Typ-/Längenfeld, Nutzdaten, Prüfsumme                                |                                                                                                                                   | standardmäßiges Ethernet-Rahmenformat → Rückwärtskompatibilität                                                                               |
| Codierung                               |                                                                                                                              |                                                                                                                                   | PAM5 (Pulse Amplitude Modulation mit 5 Levels) für Twisted-Pair                                                                               |
| Maximale Kabellänge                     | ~100 Meter, wegen Signalabschwächung und Anforderungen von CSMA/CD                                                           |                                                                                                                                   |                                                                                                                                               |
| Benutzerfreundlichkeit                  | Einfachheit in der Implementierung und Wartung                                                                               |                                                                                                                                   |                                                                                                                                               |
| Übertragungsmodi                        |                                                                                                                              | Voll-Duplex (gleichzeitig, bidirektional, ohne Kollisionen), Halb-Duplex (mit CSMA/CD), Auto-Negotiation zwischen den beiden Modi | Full-Duplex (CSMA/CD überflüssig, wird meistens genutzt), Auto-Negotiation (ermöglicht beste verfügbare Geschwindigkeit, bester Duplex-Modus) |
| Anwendungsbereiche                      |                                                                                                                              | Unternehmensnetzwerke (Backbone, Bereiche mit hohen Bandbreiten), Heimnetzwerke (verbreitet, aber wird durch Gigabit ersetzt)     | Unternehmens-/Heimnetzwerke/Serverfarmen (dort, wo hohe Übertragungsraten benötigt werden), Rechenzentren (Standard)                          |

## IEEE 802 Protokollfamilie
![image_800.png](image_800.png)

## Broadcast-Domänen verkleinern
> Zur Verbesserung der Netzwerk-Performance und Erhöhung der Sicherheit

### Einsatz von Virtual Local Area Networks (VLANs)
- **Segmentierung des Netzwerks**
  - VLANs ermöglichen Aufteilung in logische Netzwerke
    - jedes VLAN bildet eine eigene Broadcast-Domäne
    - Verkehrt wird innerhalb kleinerer Netzwerke gehalten → Begrenzung
- **Verbesserte Sicherheit**
  - Durch Trennung von Netzwerksegmenten
  - Broadcasts werden nicht über gesamtes Netzwerk verbreitet
- **VLAN tag**
  - ![image_788.png](image_788.png)

### Verwendung von Layer-3-Switches oder Routern
- **Routing zwischen VLANs**
  - können Datenverkehr zwischen VLANs steuern
- **Kontrolle und Sicherheit**
  - bieten zusätzliche Funktionen/Möglichkeiten
    - _bspw. Zugangskontrolllisten (ACL)_

### Einsatz von Subnetting auf der IP-Schicht
- **Aufteilung in kleinere IP-Netzwerke**
  - Jedes IP-Subnetz hat eigene Broadcast-Domäne
    - reduziert Broadcast-Verkehr

### Einsatz von Managed Switches
- **Konfigurierbare L2-Switche**
  - bieten erweiterte Funktionen an
    - VLAN-Konfiguration, Port-Sicherheit, Zugriffskontrollen
    - → Reduzierung von Broadcast-Domänen
    - → Erhöhung der Netzwerksicherheit


## QoS bei Ethernet-Netzwerken
> nicht von Beginn an vorhanden
> 
> könnte Perfomance und Sicherheit erhöhen
> 
> → Für **Echtzeit-Anwendungen** wie VoIP und Streaming sollten spezielle QoS-Regeln erstellt werden 
> um Latenz oder Paketverlust zu minimieren

### Implementation QoS bei Ethernet-Netzwerken
#### Einsatz von Managed Layer-2-Switches
- **Erweiterte QoS-Funktionen**
  - ermöglichen, Datenverkehr basierend auf verschiedenen Kriterien zu priorisieren
    - _bspw. Portnummer, VLAN-ID, spezifische Anwendung_

#### Priorisierung des Datenverkehrs durch 802.1Q Tagging
- **802.1Q Tagging**
  - Tagging von Ethernet-Frames mit einer Priorität
  - wird von Routern und Switches genutzt um best. Datenverkehr zu bevorzugen

#### [Einsatz von VLANs](#einsatz-von-virtual-local-area-networks-vlans)

#### Einsatz von Layer-3-QoS-Konfigurationen mit DSCP
- **Einsatz von DSCP auf IP-Schicht** (_Differentiated Services Code Point_) 
  - Markierung von IP-Paketen mit spez. Prioritätsstufen
    - Router, Switches können anhand der Markierungen priorisieren/verwalten

## Drahtlose Netze
### Uplink und Downlink
![WhatsApp Bild 2025-05-06 um 10.46.33_3072a0f4.jpg](WhatsApp Bild 2025-05-06 um 10.46.33_3072a0f4.jpg)

### Infrastrukturnetz
![image_801.png](image_801.png)
#### Station (STA)
- Rechner mit Zugriffsfunktion auf drahtlose Medium und Funktkontakt zum Access Point

#### Basic Service Set (BSS)
- Gruppe von Stationen, die dieselbe Funkfrequenz nutzen

#### Access Point
- Station, die sowohl in das Funk-LAN als auch das verbindende Festnetz integriert ist

#### Portal
- Übergang in ein anderes Festnetz

#### Distribution System
- Verbindung verschiedener Zellen um ein Netz (ESS: Extended Service Set) zu bilden

### Vergleich Infrastruktur- und AdHoc-Netzwerk
> ![image_802.png](image_802.png)


## QAM-Modulation
> ![image_803.png](image_803.png)

